<?php
/**
 * @package 友情链接
 * @version 1.0.2  */
/*
Plugin Name: 友情链接
Description: 插件提供了一个简单的方法来添加友情链接到您的网站。
Version: 1.0.2
*/

// 开启友情链接功能
add_filter( 'pre_option_link_manager_enabled', '__return_true' );

include_once(ABSPATH.'gc-admin/includes/plugin.php');

function gclpf_is_requirements_met() {

    // Check if 友情链接 Pro is active
    if ( is_plugin_active('gc-links-page-pro/gc-links-page-pro.php') && get_option('gclp_passes_req') != 'true' ) {

        return false;
    }

    return true;
}

function gclpf_disable_plugin() {

    if ( current_user_can('activate_plugins') && is_plugin_active( plugin_basename( __FILE__ )) ) {
        deactivate_plugins( plugin_basename( __FILE__ ) );
        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }
    }
}

if ( !gclpf_is_requirements_met() ) {
include_once(ABSPATH.'gc-admin/includes/plugin.php');
	add_action( 'admin_init', 'gclpf_disable_plugin' );
} else {

$upload_dir = gc_upload_dir();
$gclf_upload = $upload_dir['basedir'].'/gc-links-page/';
if( ! file_exists( $gclf_upload ) )
    gc_mkdir_p( $gclf_upload );

if (!defined('GCLP_UPLOAD_DIR')) {
    define('GCLP_UPLOAD_DIR', $gclf_upload);
}

if (!defined('GCLP_UPLOAD_URL')) {
    define('GCLP_UPLOAD_URL', $upload_dir['baseurl'].'/'.'gc-links-page/');
}

/** Require dependencies */
require_once( ABSPATH . 'gc-admin/includes/image.php' );
require_once( ABSPATH . 'gc-admin/includes/file.php' );
require_once( ABSPATH . 'gc-admin/includes/media.php' );
require_once( ABSPATH . 'gc-includes/media-template.php' );

add_filter( 'cron_schedules', 'gc_links_page_add_intervals');

	add_option( 'gclp_screenshot_size', 'small', '', 'yes' );
	add_option( 'gclp_screenshot_refresh', 'weekly', '', 'yes' );
	add_option( 'gclp_migrate', 'false', '', 'yes' );



	add_action( 'gcmu_new_blog', 'gclf_new_blog', 10, 6);

	register_activation_hook(__FILE__, 'gc_links_page_setup_schedule');
	register_deactivation_hook( __FILE__, 'gc_links_page_deactivation');



/** Admin Init **/
if ( is_admin() ) {
	add_action( 'admin_init', 'gc_links_page_settings');
	add_action( 'admin_menu', 'gclf_menu');
	add_action( 'admin_enqueue_scripts', 'gclf_admin_enqueue_scripts' );
}



	function gc_links_page_setup_schedule() {
		$screenshot_refresh = esc_attr( get_option('gclp_screenshot_refresh') );
		gc_clear_scheduled_hook( 'gc_links_page_event' );
		gc_clear_scheduled_hook( 'gc_links_page_event' );
		gc_schedule_event( time(), $screenshot_refresh, 'gc_links_page_event');
	}

	function gclf_enqueue_shortcode_scripts($posts) {
		gc_register_script(  'gclf-display-js', plugins_url( 'gc-links-page/js/gc-links-display.js', 'gc-links-page' ), array( 'jquery' ), false, true);
		gc_localize_script( 'gclf-display-js', 'ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
		gc_register_style( 'gclf-display-style',  plugins_url( 'gc-links-page/css/gc-links-display.css', 'gc-links-page' ), array(), false, 'all' );
	}

	add_action( 'gc_enqueue_scripts', 'gclf_enqueue_shortcode_scripts' );

	function gclf_admin_enqueue_scripts( $hook ) {
		if ($hook == 'links_page_gclf_subpage3-menu') {
			gc_enqueue_script( 'gclf-shortcode-js', plugins_url( 'gc-links-page/js/gc-links-shortcode.js', 'gc-links-page' ), array( 'jquery', 'jquery-ui-tabs' ), null, true );
			gc_enqueue_style( 'gclf-style',  plugins_url( 'gc-links-page/css/gc-links-page.css', 'gc-links-page' ), null, null, false );
			gc_enqueue_style( 'ti-style',  plugins_url( 'gc-links-page/css/themify-icons.css', 'gc-links-page' ), null, null, false );
		} 

	}

function gc_links_page_add_intervals($schedules) {
		$schedules['twodays'] = array(
			'interval' => 172800,
			'display' => __('Every Other Day')
		);
		$schedules['threedays'] = array(
			'interval' => 259200,
			'display' => __('Every Three Days')
		);
		$schedules['weekly'] = array(
			'interval' => 604800,
			'display' => __('Weekly')
		);
		$schedules['biweekly'] = array(
			'interval' => 1209600,
			'display' => __('Every Two Weeks')
		);
		$schedules['monthly'] = array(
			'interval' => 2635200,
			'display' => __('Monthly')
		);
		return $schedules;
	}

	function gc_links_page_deactivation() {
		gc_clear_scheduled_hook( 'gc_links_page_event' );
	}


function gclf_menu() {

		$gclf_subpage3 = add_submenu_page(
			'link-manager.php',
			'友情链接 | 短码',
			'短码',
			'manage_options',
			'gclf_subpage3-menu',
			'gclf_shortcode_page');

	}

/**
 * Query Filter for Custom Post Types
 */
 function gclf_query_filter($query) {

	global $pagenow;
  if ( is_admin() && $query->query['post_type'] == 'gclp_link' && $pagenow == 'edit.php') {
	$query->set( 'orderby', 'link_id' );
    $query->set( 'order', 'DESC' );
  }
}


add_action('pre_get_posts','gclf_query_filter');

/**
 * Change edit.php page
*/



/**
 * Edit Custom Post Type List
 */

 add_action( 'manage_gclp_link_posts_custom_column' , 'gclf_custom_columns', 10, 2 );


function gclf_custom_columns( $column, $post_id ) {
	switch ( $column ) {
		case 'id':
			echo $post_id;
			break;
		case 'screenshot':
			$display = get_post_meta( $post_id, 'gclp_display', true );
			$image = get_the_post_thumbnail( $post_id, 'thumbnail' );
			echo $image.'<p id="gclp_display_'.$post_id.'" class="hidden">'.$display.'</p>';
			break;


	case 'description':
			$content_post = get_post($post_id);
			$content = $content_post->post_content;
			$content = apply_filters('the_content', $content);
			$content = str_replace(']]>', ']]&gt;', $content);
			echo '<div id="gclf_description_'.$post_id.'">'.$content.'</div>';
			break;

	}
}


function gclf_link_display_title( $title, $id = null ) {
	if (is_admin()) {
		if (get_post_type($id) == 'gclp_link') {
			$display = get_post_meta( $id, 'gclp_display', true );
			if ($display == '') {
				$display = $title;
			}
			return $display;
		} else { return $title; }
	} else { return $title; }
}
add_filter( 'the_title', 'gclf_link_display_title', 10, 2 );


/*将屏幕截图元框移动到标题之前*/

add_action('edit_form_after_title', function() {
    global $post, $gc_meta_boxes, $typenow;
	if ($typenow == 'gclp_link') {
		do_meta_boxes(get_current_screen(), 'advanced', $post);
		unset($gc_meta_boxes[get_post_type($post)]['advanced']);
	}
});


function gclf_display_func() {

	global $post;
	// Nonce field to validate form request came from current site
	gc_nonce_field( basename( __FILE__ ), 'gclf_fields' );

	// Get the display data if it's already been entered
	$display = get_post_meta( $post->ID, 'gclp_display', true );
	if ($display == "Auto Draft") { $display = ''; }

    echo '<label for="display">链接名称</label>
    <p class="description">此字段默认为链接域。</p>
    <input id="gclp_display" name="gclp_display" maxlength="255" type="text" value="'.$display.'">';

}

function gclf_file_get_contents_curl($url) {
    $ch = curl_init();

    curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
    curl_setopt($ch, CURLOPT_HEADER, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);

    $data = curl_exec($ch);
    curl_close($ch);

    return $data;
}


add_filter('gettext', 'gclf_text_filter', 20, 3);
/*
 * Change the text in the admin for my custom post type
 *
**/
function gclf_text_filter( $translated_text, $untranslated_text, $domain ) {

  global $typenow;

  if( is_admin() && 'gclp_link' == $typenow )  {

    //make the changes to the text
    switch( $untranslated_text ) {

        case 'Enter title here':
          $translated_text = __( 'Enter 链接URL','text_domain' );
        break;

     }
   }
   return $translated_text;
}

function gclf_array_push_assoc($array, $key, $value){
$array[$key] = $value;
return $array;
}

function gclf_filter_metadata($array){
$mk = array();
foreach($array as $k => $v){
if(is_array($v) && count($v) == 1){
$mk = gclf_array_push_assoc($mk, $k, $v[0]);
} else {
$mk = gclf_array_push_assoc($mk, $k, $v);
}
}
return $mk;
}

// 短码
function gclf_shortcode_page() {
	global $gcdb;
	?>
		<h2>短码</h2>
		<p class="description">在这里，您可以根据选择的选项生成短码。</p>

        <div id="gclf-sb">
  <div id="tabs-1" aria-labelledby="ui-id-1">
    <h3>陈列</h3>
    <hr style="border: 1px solid; width: 50%;" align="left">
    <div class="radio-i">
  	<p>显示方式</p>
    <label><input name="gclf-display" value="grid" type="radio"><i class="ti-size-xxl ti-layout-grid3-alt"></i><br><span>表格</span></label>
  	<label><input name="gclf-display" value="list" type="radio"><i class="ti-size-xxl ti-layout-list-thumb-alt"></i><br><span>列表</span></label>
    </div>
  </div>
  <br><br>
  <div id="tabs-2">
  <h3>显示设置</h3>
  <hr style="border: 1px solid; width: 50%;" align="left">
  <p class="description">选择上面的显示方式以查看该显示方式的可用设置。</p>
  <div class="grid radio-no-i">
  	<p>网格列</p>
    <label><input type="radio" name="gclf-columns" value="2"><br><span>2 列</span></label>
  	<label><input type="radio" name="gclf-columns" value="3"><br><span>3 列</span></label>
  	<label><input type="radio" name="gclf-columns" value="4"><br><span>4 列</span></label>
  	<label><input type="radio" name="gclf-columns" value="5"><br><span>5 列</span></label>
  	<label><input type="radio" name="gclf-columns" value="6"><br><span>6 列</span></label>
    <br>
 </div>
  </div>
  <br><br>
  <div id="tabs-3">
  <h3>链接排序</h3>
  <hr style="border: 1px solid; width: 50%;" align="left">
  <div class="radio-no-i">
  	<p>排序字段</p>
  	<label><input type="radio" name="gclf-order" value="link_name"><br><span>标题 (链接名称)</span></label>
  	<label><input type="radio" name="gclf-order" value="link_id"><br><span>ID</span></label>
  	<label><input type="radio" name="gclf-order" value="link_updated"><br><span>时间</span></label>
  	<label><input type="radio" name="gclf-order" value="link_rating"><br><span>评级</span></label>
  	<label><input type="radio" name="gclf-order" value="rand"><br><span>随机</span></label>
    <br>
   <div>
  	<p>升降序</p>
  	<label><input type="radio" name="gclf-orderby" value="ASC"><br><span>升序</span></label>
  	<label><input type="radio" name="gclf-orderby" value="DESC"><br><span>降序</span></label>
    <br>
  </div>
  <br>

  </div>

  <br><br>
  <div id="tabs-4">
  <h3>图片</h3>
  <hr style="border: 1px solid; width: 50%;" align="left">
  <div class="radio-no-i">
    <div>
  	<p>图片尺寸</p>
  	<label><input type="radio" name="gclf-image-size" value="full"><br><span>原始大小</span></label>
    <br>
    </div></div><div class="checks">
  	<p>图片样式</p>
    <label><input type="checkbox" name="gclf-image-style" value="border"><br><span>边框</span></label>
  	<label><input type="checkbox" name="gclf-image-style" value="shadow"><br><span>阴影</span></label>
  </div></div>
  <br><br>
  <div id="tabs-5" >
  <h3>标题</h3>
  <hr style="border: 1px solid; width: 50%;" align="left">
  <div class="radio-no-i">
    </div><div class="checks">
  	<p>标题字体样式?</p>
    <label><input type="checkbox" name="gclf-title-style" value="bold"><br><span>粗体</span></label>
  	<label><input type="checkbox" name="gclf-title-style" value="italic"><br><span>斜体</span></label>
  	<label><input type="checkbox" name="gclf-title-style" value="underline"><br><span>下划线</span></label>
    <br>
    </div><div class="radio-no-i">
  	<p>标题如何对齐?</p>
    <label><input type="radio" name="gclf-title-align" value="left"><br><span>左对齐</span></label>
  	<label><input type="radio" name="gclf-title-align" value="right"><br><span>右对齐</span></label>
  	<label><input type="radio" name="gclf-title-align" value="center"><br><span>居中</span></label>
    <br>
  </div>
  	<p>字体大小</p>
    <label for="gclf-title-size">文字大小: </label><input name="gclf-title-size" type="text"> px<br>
  </div>
  <br><br>
  <div id="tabs-6" >
  <h3>描述</h3>
  <hr style="border: 1px solid; width: 50%;" align="left">
  <div class="radio-no-i">
  	<p>是否显示描述</p>
    <label><input type="radio" name="gclf-desc" value="content"><br><span>显示</span></label>
  	<label><input type="radio" name="gclf-desc" value="none"><br><span>不要</span></label><br>
    <br>
    </div><div class="checks">
  	<p>描述的样式?</p>
    <label><input type="checkbox" name="gclf-desc-style" value="bold"><br><span>粗体</span></label>
  	<label><input type="checkbox" name="gclf-desc-style" value="italic"><br><span>斜体</span></label>
  	<label><input type="checkbox" name="gclf-desc-style" value="underline"><br><span>下划线</span></label>
    <br>
    </div><div class="radio-no-i">
  	<p>描述如何对齐?</p>
    <label><input type="radio" name="gclf-desc-align" value="left"><br><span>左对齐</span></label>
  	<label><input type="radio" name="gclf-desc-align" value="right"><br><span>右对齐</span></label>
  	<label><input type="radio" name="gclf-desc-align" value="center"><br><span>居中</span></label>
    <br>
	 </div><div class="radio-no-i">
  	<p>描述添加链接吗？</p>
    <label><input type="radio" name="gclf-description_link" value="no"><br><span>否</span></label>
  	<label><input type="radio" name="gclf-description_link" value="yes"><br><span>是</span></label>
    <br>
  </div>
  	<p>字体大小</p>
    <label for="gclf-desc-size">文字大小: </label><input name="gclf-desc-size" type="text"> px<br>
  </div>
  <br><br>
	<div id="tabs-7" >
		<h3>分类</h3>
		<hr style="border: 1px solid; width: 50%;" align="left">
		<div class="checks">
			<div>
				<p>选择分类</p>
				<?php
				$terms = $gcdb->get_results("SELECT T1.term_id AS id, T1.name AS name FROM {$gcdb->terms} T1, {$gcdb->term_taxonomy} T2 WHERE T1.term_id = T2.term_id AND T2.taxonomy = 'link_category'");

				foreach($terms as $term) {
					echo '<label><input type="checkbox" name="gclf-sort" value="'.$term->id.'"><br><span>'.$term->name.'</span></label>';
				}
				?>
				<br>
			</div>
		</div>
	<br>
  </div>

</div>
<div class="gclf-shortcode">
<p>您的短码</p>
	<textarea id="final-shortcode">[gc_links_page]</textarea>
</div>
<div class="clear">
</div>
</div>
    <?php
}


	function gc_links_page_settings() { // whitelist options
		register_setting( 'gc-links-page-option-group', 'gclp_screenshot_size' );
		register_setting( 'gc-links-page-option-group', 'gclp_screenshot_refresh' );
		register_setting( 'gc-links-page-option-group', 'gclp_migrate' );
	}

	/* 短码 */

	add_filter( 'the_content', 'gclf_remove_autop', 0 );
	function gclf_remove_autop( $content )
	{
		 global $post;
		 // Check for single page and image post type and remove
		 if ( $post->post_type == 'gclp_link' )
			  remove_filter('the_content', 'gcautop');

		 return $content;
	}

	function gclf_shortcode($atts){
		global $gcdb;

		if (get_option('gclp_grid') != false) {
			$dis = get_option('gclf_grid');
		} else { $dis = 'grid'; }
		if (get_option('gclp_width') != false) {
			$col = get_option('gclf_width');
		} else { $col = '3'; }

		if (get_option('gclpf_grid') != false) {
			$dis = get_option('gclff_grid');
		} else { $dis = 'grid'; }
		if (get_option('gclpf_width') != false) {
			$col = get_option('gclff_width');
		} else { $col = '3'; }

		$vars = shortcode_atts( array(
			'ids' => '',
			'type' => '',
			'display' => 'grid',
			'cols' => '3',
			'order' => 'DESC', // 正序 倒叙
			'orderby' => 'link_id', //排序字段
			'sort' => '',  // 分类
			'img_size' => 'medium',
			'img_style' => '',
			'title_style' => '',
			'desc' => '',
			'description' => '',
			'description_link' => 'yes',
			'desc_style' => '',
			), $atts );

		$default_num_posts = get_option( 'posts_per_page' );
		$display = $vars['display'];
		$type = $vars['type'];
		if ($type != '' && $display == 'grid') {
			$display = $type;
		}
		$cols = $vars['cols'];

		$order = $vars['order'];
		$meta = '';
		$orderby = $vars['orderby'];
		$sort = $vars['sort'];
		if ($sort == 'random' && $orderby == 'link_id') {
			$oderby = 'rand';
		}

		$img_size = $vars['img_size'];
		$img_style = $vars['img_style'];
		$title_style = $vars['title_style'];
		$desc = $vars['desc']; 
		$description = $vars['description'];
		if ($description == 'yes' && $desc == '') {
			$desc = 'content';
		}
		$description_link = $vars['description_link'];
		$desc_style = $vars['desc_style'];
		$ids = $vars['ids'];


		gc_enqueue_style('gclf-display-style');
		gc_enqueue_script('gclf-display-js');

		global $gcdb;
		$grid = '';
		$list = '';
		$gallery = '';
		$i = 0;

		// 计算分页
		$page = 1;
		$number_per_page = 30;
		$limit = $number_per_page;
		if ( get_query_var( 'paged' ) ){
			$page = get_query_var( 'paged' );
			$limit = (($number_per_page * $page)-$number_per_page-1) .','.$number_per_page;
		}

		$query_args = array('order' => $order, 'orderby' => $orderby, 'metakey' => $meta, 'category' => $sort, 'limit' => $limit);

		if ($ids != '') {
			$idarr = explode(',', $ids);
			$query_args['post__in'] = $idarr;
		}
		remove_all_filters('posts_orderby');
		$gc_query = get_bookmarks( $query_args );
		//print('<pre>'.print_r($gc_query,true).'</pre>');

		foreach($gc_query as $link) {

      		$url = $link->link_url;

      		# 链接方式
      		$link_target = $link->link_target; 

			// 图像
			$img = '<img src="'.$link->link_image.'" alt="" style="'.$img_style.'">';

			// 标题
			$title_display = $link->link_name;


			// 描述
			$description = '';
			if ($desc == 'content') {
				$description = $link->link_description;
				$description = '<p class="gclf_desc" style="'.$desc_style.'">'.$description.'</p>';
			}

			if ($description_link == 'yes') {
				$description = $description.'</a>';
			} else {
				$description = '</a>'.$description;
			}

			if ($display == 'grid') {
				$gallery .= '<figure id="gallery-item-'.$i.'" class="gallery-item gclf-item">
				<div class="gallery-icon landscape">
				<a class="gclf_link" href="'.$url.'" target="'.$link_target.'">
				'.$img.'
				<p class="gclf_display" style="'.$title_style.'" >'.$title_display.'</p>
				'.$description.'
				</div>
				</figure>';
			} elseif ($display == 'list') {
				$list .= '<div id="gclf_list-item-'.$i.'" class="list-item gclf-item">
				<a class="gclf_link" href="'.$url.'" target="'.$link_target.'">
				<div class="list-img">'.$img.'</div>
				<p class="gclf_display" style="'.$title_style.'" >'.$title_display.'</p>
				'.$description.'
				</div>
				<hr>';
			}
			$i++;

		}

		if ($display == 'grid') {
			$output = '<div style="clear:both;"></div><div id="gallery-gclf" class="galleryid-gclf gallery-columns-'.$cols.' gclf-display">'.$gallery.'</div><div style="clear:both;"></div>';
		} elseif ($display == 'list') {
			$output = '<div style="clear:both;"></div><div id="list-gclf" class="listid-gclf gclf-display">'.$list.'</div><div style="clear:both;"></div>';
		}

		$_bookmark_count = $gcdb->get_row( "SELECT count(1) AS count FROM {$gcdb->links}" );

		// v1.0.2
		// gongenlin
		// 用于分页
		$big=999;
		$args = array(
			'base'         => str_replace($big,'%#%',esc_url(get_pagenum_link($big))),
			'format'       => '',
			'total'        => ceil( $_bookmark_count->count / $number_per_page ), //共计多少页
			'current'      => $page, //当前页码
			'show_all'     => False,
			'end_size'     => 1,
			'mid_size'     => 5,
			'prev_next'    => True,
			'prev_text'    => __('« 上一页'),
			'next_text'    => __('下一页 »'),
			'type'         => 'plain',
			'add_args'     => False,
			'add_fragment' => '',
			'before_page_number' => '',
			'after_page_number' => ''
		);

		// 分页
		$output .= '<div style="clear:both;"></div><div id="list-gclf" class="listid-gclf gclf-display">'.paginate_links( $args ).'</div><div style="clear:both;"></div>';

		return $output;
	}
	add_shortcode('gc_links_page', 'gclf_shortcode');
}
?>
